@@ -70,9 +70,9 @@ mesh_to_coords <- function(meshcode, ...) {
   lat.c  <- as.numeric(sprintf("%.10f", lat.c)) 
   long.c <- as.numeric(sprintf("%.10f", long.c))
   
-  res <- data.frame(lng_center = long.c,
+  res <- data.frame(lng_center  = long.c,
                     lat_center  = lat.c, 
-                    lng_error  = long.c - long,
+                    lng_error   = long.c - long,
                     lat_error   = lat.c - lat
                     )
   finename_centroid <- function(df, last_code) {
@@ -80,31 +80,39 @@ mesh_to_coords <- function(meshcode, ...) {
     lng_center <- lat_center <- lng_error <- lat_error <- NULL
     
     if (last_code == 1) {
-      res <- df %>% 
-        dplyr::mutate(lat_center = lat_center - (lat_error / 2),
-                      lng_center = lng_center - (lng_error / 2))
+      df$lat_center = 
+        (df$lat_center + df$lat_error) - (df$lat_error / 2) * 3
+      df$lng_center = 
+        (df$lng_center + df$lng_error) - (df$lng_error / 2) * 3
     } else if (last_code == 2) {
-      res <- df %>% 
-        dplyr::mutate(lat_center = lat_center - (lat_error / 2),
-                      lng_center = lng_center + (lng_error / 2))
+      df$lat_center = 
+        (df$lat_center + df$lat_error) - (df$lat_error / 2) * 3
+      df$lng_center = 
+        (df$lng_center + df$lng_error) - (df$lng_error / 2)
     } else if (last_code == 3) {
-      res <- df %>% 
-        dplyr::mutate(lat_center = lat_center + (lat_error / 2),
-                      lng_center = lng_center - (lng_error / 2))
+      df$lat_center = 
+        (df$lat_center + df$lat_error) - (df$lat_error / 2)
+      df$lng_center = 
+        (df$lng_center + df$lng_error) - (df$lng_error / 2) * 3
     } else if (last_code == 4) {
-      res <- df %>% 
-        dplyr::mutate(lat_center = lat_center + (lat_error / 2),
-                      lng_center = lng_center + (lng_error / 2)) 
+      df$lat_center = 
+        (df$lat_center + df$lat_error) - (df$lat_error / 2)
+      df$lng_center = 
+        (df$lng_center + df$lng_error) - (df$lng_error / 2)
     }
     
-    res <- res %>% 
-      dplyr::mutate(lat_error = lat_error / 2,
-                    lng_error = lng_error / 2)
+    df$lat_error = df$lat_error / 2
+    df$lng_error = df$lng_error / 2
+    res <- df
     
     return(res)
   }
   
   if (exists("code9")) {
+    
+    res$lat_error = 0.004165
+    res$lng_error = 0.00625
+    
     res <- finename_centroid(res, code9)
   }
   if (exists("code10")) {
